package MT::Plugin::SKR::MightyCMS::CustomizeLabels::Entry;
#           Copyright (c) 2008 SKYARC System Co.,Ltd.
#           @see http://www.skyarc.co.jp/
use strict;
use warnings;
use MT::Util qw( encode_html );
#use Data::Dumper;#DEBUG

use vars qw( $PLUGIN_NAME $VERSION );
$PLUGIN_NAME = 'CustomizeEntryLabels';
$VERSION = '1.00';

### Registration of the MT::Plugin
use base qw( MT::Plugin );
my $plugin = __PACKAGE__->new({
    name    => $PLUGIN_NAME,
    version => $VERSION,
    key     => lc $PLUGIN_NAME,
    id      => lc $PLUGIN_NAME,
    author_name => 'SKYARC System Co.,Ltd.',
    author_link => 'http://www.skyarc.co.jp/',
    description => <<HTMLHEREDOC,
Enable you to customize the labels in entry editing screen.
HTMLHEREDOC
    blog_config_template => 'CustomizeLabel.tmpl',
    settings => new MT::PluginSettings([
        [ 'title',      { Default => undef, Scope => 'blog' }],
        [ 'body',       { Default => undef, Scope => 'blog' }],
        [ 'extended',   { Default => undef, Scope => 'blog' }],
        [ 'excerpt',    { Default => undef, Scope => 'blog' }],
        [ 'tags',       { Default => undef, Scope => 'blog' }],
        [ 'keywords',   { Default => undef, Scope => 'blog' }],
        [ 'basename',   { Default => undef, Scope => 'blog' }],
        [ 'categories', { Default => undef, Scope => 'blog' }],
        [ 'feedback',   { Default => undef, Scope => 'blog' }],
        [ 'comments',   { Default => undef, Scope => 'blog' }],
        [ 'trackbacks', { Default => undef, Scope => 'blog' }],
    ]),
});
MT->add_plugin( $plugin );

sub instance { $plugin; }

### Registry
sub init_registry {
    my $plugin = shift;
    $plugin->registry({
        callbacks => {
           'MT::App::CMS::template_source.edit_entry' => \&_source_edit_entry,
        },
    });
}



### Replace 
sub _source_edit_entry {
    my( $eh, $app, $tmpl ) = @_;
    return
        unless $app->{query}->param('_type') eq 'entry';
    my $scope = "blog:". $app->{query}->param('blog_id');

    ### Title
    my $old = quotemeta( <<'HTMLHEREDOC' );
        label="<__trans phrase="Title">"
HTMLHEREDOC
    my $replace = encode_html( &instance->get_config_value( 'title', $scope ) || '' );
    my $new = <<HTMLHEREDOC;
        label="$replace"
HTMLHEREDOC
    $$tmpl =~ s/$old/$new/ if $replace;

    ### Body
    $old = quotemeta( <<'HTMLHEREDOC' );
                    <label><a href="javascript:void(0);"><__trans phrase="Body"></a></label>
HTMLHEREDOC
    $replace = encode_html( &instance->get_config_value( 'body', $scope ) || '' );
    $new = <<HTMLHEREDOC;
                    <label><a href="javascript:void(0);">$replace</a></label>
HTMLHEREDOC
    $$tmpl =~ s/$old/$new/ if $replace;

    ### Extended
    $old = quotemeta( <<'HTMLHEREDOC' );
                    <label><a href="javascript:void(0);"><__trans phrase="Extended"></a></label>
HTMLHEREDOC
    $replace = encode_html( &instance->get_config_value( 'extended', $scope ) || '' );
    $new = <<HTMLHEREDOC;
                    <label><a href="javascript:void(0);">$replace</a></label>
HTMLHEREDOC
    $$tmpl =~ s/$old/$new/ if $replace;

    ### Excerpt
    $old = quotemeta( <<'HTMLHEREDOC' );
        label="<__trans phrase="Excerpt">"
HTMLHEREDOC
    $replace = encode_html( &instance->get_config_value( 'excerpt', $scope ) || '' );
    $new = <<HTMLHEREDOC;
        label="$replace"
HTMLHEREDOC
    $$tmpl =~ s/$old/$new/ if $replace;

    ### Tags
    $old = quotemeta( <<'HTMLHEREDOC' );
        label="<__trans phrase="Tags">"
HTMLHEREDOC
    $replace = encode_html( &instance->get_config_value( 'tags', $scope ) || '' );
    $new = <<HTMLHEREDOC;
        label="$replace"
HTMLHEREDOC
    $$tmpl =~ s/$old/$new/ if $replace;

    ### Keywords
    $old = quotemeta( <<'HTMLHEREDOC' );
        label="<__trans phrase="Keywords">"
HTMLHEREDOC
    $replace = encode_html( &instance->get_config_value( 'keywords', $scope ) || '' );
    $new = <<HTMLHEREDOC;
        label="$replace"
HTMLHEREDOC
    $$tmpl =~ s/$old/$new/ if $replace;

    ### Basename
    $old = quotemeta( <<'HTMLHEREDOC' );
    <$mt:setvar name="basename_label" value="<__trans phrase="Basename">"$>
HTMLHEREDOC
    $replace = encode_html( &instance->get_config_value( 'basename', $scope ) || '' );
    $new = <<HTMLHEREDOC;
    <\$mt:setvar name="basename_label" value="$replace"\$>
HTMLHEREDOC
    $$tmpl =~ s/$old/$new/ if $replace;

    ### Categories
    $old = quotemeta( <<'HTMLHEREDOC' );
            label="<__trans phrase="Categories">"
HTMLHEREDOC
    $replace = encode_html( &instance->get_config_value( 'categories', $scope ) || '' );
    $new = <<HTMLHEREDOC;
            label="$replace"
HTMLHEREDOC
    $$tmpl =~ s/$old/$new/ if $replace;

    ### Feedback
    $old = quotemeta( <<'HTMLHEREDOC' );
        label="<__trans phrase="Feedback">">
HTMLHEREDOC
    $replace = encode_html( &instance->get_config_value( 'feedback', $scope ) || '' );
    $new = <<HTMLHEREDOC;
            label="$replace">
HTMLHEREDOC
    $$tmpl =~ s/$old/$new/ if $replace;

    ### Comments
    $old = quotemeta( '<__trans phrase="Comments"/>' );
    $replace = encode_html( &instance->get_config_value( 'comments', $scope ) || '' );
    $$tmpl =~ s/$old/$replace/ if $replace;

    ### TrackBacks
    $old = quotemeta( '<__trans phrase="TrackBacks"/>' );
    $replace = encode_html( &instance->get_config_value( 'trackbacks', $scope ) || '' );
    $$tmpl =~ s/$old/$replace/ if $replace;
}

1;